package com.yiqi.order.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.yiqi.order.domain.dto.OrderClothItemOutFactoryQueryDTO;
import org.apache.ibatis.annotations.Mapper;
import com.yiqi.order.domain.OrderClothAdjunct;

/**
 * 订单衣服附件Mapper接口
 *
 * @author xiaohei
 * @date 2023-10-06
 */
@Mapper
public interface OrderClothAdjunctMapper extends BaseMapper<OrderClothAdjunct> {
    /**
     * 查询订单衣服附件
     *
     * @param id 订单衣服附件主键
     * @return 订单衣服附件
     */
    public OrderClothAdjunct selectOrderClothAdjunctById(Long id);

    /**
     * 查询订单衣服附件列表
     *
     * @param orderClothAdjunct 订单衣服附件
     * @return 订单衣服附件集合
     */
    public List<OrderClothAdjunct> selectOrderClothAdjunctList(OrderClothAdjunct orderClothAdjunct);

    /**
     * 新增订单衣服附件
     *
     * @param orderClothAdjunct 订单衣服附件
     * @return 结果
     */
    public int insertOrderClothAdjunct(OrderClothAdjunct orderClothAdjunct);

    /**
     * 修改订单衣服附件
     *
     * @param orderClothAdjunct 订单衣服附件
     * @return 结果
     */
    public int updateOrderClothAdjunct(OrderClothAdjunct orderClothAdjunct);

    /**
     * 删除订单衣服附件
     *
     * @param id 订单衣服附件主键
     * @return 结果
     */
    public int deleteOrderClothAdjunctById(Long id);

    /**
     * 批量删除订单衣服附件
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteOrderClothAdjunctByIds(Long[] ids);

    OrderClothAdjunct selectOrderClothAdjunctByAdjunctNo(String adjunctNo);

    /**
     * 查询待出厂的订单衣服附件列表
     * @param orderClothItemOutFactoryQueryDTO
     * @return
     */
    List<OrderClothAdjunct> queryWaitFactoryOrderClothAdjunctList(OrderClothItemOutFactoryQueryDTO orderClothItemOutFactoryQueryDTO);
}
